==> qt-creator-1.0.0-src.zip: qt-creator-1.0.0-src/src/plugins/quickopen/quickopenconstants.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact:  Qt Software Information (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
**************************************************************************/

#ifndef QUICKOPENCONSTANTS_H
#define QUICKOPENCONSTANTS_H

namespace QuickOpen {
namespace Constants {

const char * const FILTER_OPTIONS_PAGE = "Filters";
const char * const QUICKOPEN_CATEGORY = "Locator";
const char * const TASK_INDEX = "QuickOpen.Task.Index";

} // namespace Constants
} // namespace QuickOpen

#endif // QUICKOPENCONSTANTS_H

==> qt-creator-1.1.0-src.zip: qt-creator-1.1.0-src/src/plugins/quickopen/quickopenconstants.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact:  Qt Software Information (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
**************************************************************************/

#ifndef QUICKOPENCONSTANTS_H
#define QUICKOPENCONSTANTS_H

#include <QtCore/QtGlobal>

namespace QuickOpen {
namespace Constants {

const char * const FILTER_OPTIONS_PAGE = QT_TRANSLATE_NOOP("Locator", "Filters");
const char * const QUICKOPEN_CATEGORY = QT_TRANSLATE_NOOP("Locator", "Locator");
const char * const TASK_INDEX = "QuickOpen.Task.Index";

} // namespace Constants
} // namespace QuickOpen

#endif // QUICKOPENCONSTANTS_H
